package webapi

import (
	"fmt"
	"log"
	"net/http"

	"gitea.nehmer.net/torben/dyndns/service"
)

func init() {
	router.HandleFunc("/update", handleUpdate)
}

func handleUpdate(w http.ResponseWriter, r *http.Request) {
	err := r.ParseForm()
	if err != nil {
		http.Error(w, err.Error(), http.StatusBadRequest)
		return
	}

	ur, err := createUpdateRequestFromForm(r.Form)
	if err != nil {
		http.Error(w, err.Error(), http.StatusBadRequest)
		return
	}

	uc, err := service.LoadConfigForUser(ur.UserName, ur.Password)
	if err != nil {
		if _, ok := err.(*service.UnauthorizedError); ok {
			http.Error(w, err.Error(), http.StatusUnauthorized)
		} else {
			http.Error(w, err.Error(), http.StatusInternalServerError)
		}
		log.Printf("Authorization failed: %v", err)
		return
	}

	w.Header().Set("Content-Type", "text/plain")
	fmt.Fprintln(w, "OK")
	fmt.Fprintln(w, ur.PrettyPrint())
	log.Println(ur.PrettyPrint())
	log.Println(ur.IPv6Net.IP)
	log.Println(ur.IPv6Net.Mask)
	log.Printf("Request PW: %s, Config PW: %s", ur.Password, uc.PassWord)
	fmt.Fprintln(w, "Unmarshalled userconfig:")
	fmt.Fprintln(w, uc.PrettyPrint())
	fmt.Fprintln(w, "WebAPI Config:")
	fmt.Fprintln(w, C.PrettyPrint())
	fmt.Fprintln(w, "Service Config:")
	fmt.Fprintln(w, service.C.PrettyPrint())

	for _, other := range uc.Others {
		log.Printf("Other %s, IID %v, UR V6NEt: %v, merged: %v",
			other.DNS, other.V6IID, ur.IPv6Net,
			other.ConvertIIDToAddress(ur.IPv6Net))
	}
}
